<?php
/*
 * Plugin Name: Rating
 * Author: Divesh Kumar, Paritosh Gautam
 * Version: 1.2
 * Description: Plugin helps to rate the content with custom images for rating and a lot more.
 */
require_once (dirname(__FILE__) . '/rating.php');
require_once (dirname(__FILE__) . '/data_access.php');
require_once (dirname(__FILE__) . '/rating_html.php');
require_once (dirname(__FILE__) . '/rating_settings.php');
require_once (dirname(__FILE__) . '/widget.php');
require_once (dirname(__FILE__) . '/ajax-rating.php');

$rating_db_version = "1.0";
wp_enqueue_style('rating-plugin', plugins_url( '/css/rating-styles.css', __FILE__ ));
wp_enqueue_script('rating-plugin', plugins_url( '/scripts/rating.js', __FILE__ ), array("jquery"), '', true);


//allow redirection, even if my theme starts to send output to the browser
add_action('init', 'do_output_buffer');
add_action('wp_head', 'custom_scripts');
function do_output_buffer() {
  ob_start();
}


function custom_scripts() {
  ?>
  <script type='text/javascript'>
  	ajax_url = '<?php echo admin_url('admin-ajax.php'); ?>';
  </script>
  <?php 
}


/**
 * @method
 * This method is for the rating box integration with content.
 */
function add_rating_to_content($content) {
  $p = $GLOBALS['post'];
  // checking if rating is enabled
  $ratingEnabled = true; // TODO: Admin Config
  global $post;
  $data = new DataAccess();
  $entity = $data->get_entity_id_by_name($post->post_type);
  $content = "<div class='content-wrap'>". $content . "</div>";
  $rating_activation = $data->db->get_row("SELECT entity_enable as is_enabled, most_rated_flag from wp_admin_rating_config WHERE id = '$entity->id'");
  if ($rating_activation->most_rated_flag > 0) {
    $is_most_rated_content = $data->getMostRatedContent($post);
    
    if ($is_most_rated_content === true) {
      $content = "<div class='most-rated-content'>" . __("Most Rated") . "</div>" . $content;
    }
  }
  if ($rating_activation->is_enabled > 0) {
    // Rating position
    $rating_box_position = 'bottom'; // TODO: Admin Config (Top, Bottom, Both)
    // getting rating widget
    $rating = new Rating();
    switch($rating_box_position) {
      case 'top':
        $content = $rating->generateRatingBox($post) . $content;
        break;
      case 'bottom':
        $content = $content . $rating->generateRatingBox($post) ;
        break;
      case 'both':
        $content = $rating->generateRatingBox($post) . $content . $rating->generateRatingBox($post);
        break;
    }
    return $content;
  }
  else
    return $content;

}
/**
 *
 * This method would hook into comment content.
 * @param unknown_type $content
 */
function add_rating_to_comment($content) {
  // checking if rating is enabled
  $data = new DataAccess();
  $rating_activation = $data->db->get_row("SELECT entity_enable as is_enabled from wp_admin_rating_config WHERE entity_type_name = 'comment'");
  $comment = get_comment(get_comment_ID());

  if ($rating_activation->is_enabled > 0) {
    // Rating position
    $rating_box_position = 'bottom'; // TODO: Admin Config (Top, Bottom, Both)
    // getting rating widget
    $rating = new Rating();
    switch($rating_box_position) {
      case 'top':
        $content = $rating->generateRatingBox($comment) . $content;
        break;
      case 'bottom':
        $content = $content . $rating->generateRatingBox($comment) ;
        break;
      case 'both':
        $content = $rating->generateRatingBox($comment) . $content . $rating->generateRatingBox($comment);
        break;
    }
    return $content;
  }

}

// Calling actions
add_action('the_content', 'add_rating_to_content');
add_action('comment_text', 'add_rating_to_comment');

function Rating_install() {
  global $wpdb;
  //global $rating_db_version;
  require_once(ABSPATH . 'wp-admin/includes/upgrade.php');

  $t_admin_rating_config = $wpdb->prefix . 'admin_rating_config';
  $sql_admin_rating_config = "CREATE TABLE $t_admin_rating_config (
  id mediumint(9) NOT NULL AUTO_INCREMENT,
  entity_type_name VARCHAR(50) NOT NULL,
  most_rated_flag boolean NOT NULL DEFAULT 0,
  entity_factors_mode boolean NOT NULL DEFAULT 0,
  entity_enable boolean NOT NULL DEFAULT 1,
  theme VARCHAR(255) NOT NULL,
   
  PRIMARY KEY id (id)
  );";
  

  $t_rating_factors = $wpdb->prefix . 'rating_factors';
  $sql_rating_factors = "CREATE TABLE $t_rating_factors (
  id mediumint(9) NOT NULL AUTO_INCREMENT,
  factor VARCHAR(50) NOT NULL,
  enable_factor boolean NOT NULL DEFAULT 1,
   
  PRIMARY KEY id (id)
  );";

  $t_entity_rating_factors = $wpdb->prefix . 'entity_rating_factors';
  $sql_entity_rating_factors = "CREATE TABLE $t_entity_rating_factors (
  id int(11) NOT NULL AUTO_INCREMENT,
  entity_id mediumint(9) NOT NULL DEFAULT 0,
  factor_name VARCHAR(50) NULL DEFAULT NULL,
  weight FLOAT NOT NULL,
   
  PRIMARY KEY id (id)
  );";

  $t_rating_score = $wpdb->prefix . 'rating_scores';
  $sql_rating_score = "CREATE TABLE $t_rating_score (
  id int(11) NOT NULL AUTO_INCREMENT,
  entity_content_id int(11) NOT NULL DEFAULT 0,
  entity_type_name VARCHAR(50) NOT NULL,
  factor_name VARCHAR(50) NULL DEFAULT NULL,
  rating_score int(11) NOT NULL DEFAULT 0,
  country VARCHAR(50) NULL DEFAULT NULL,
  state VARCHAR(50) NULL DEFAULT NULL,
  time TIMESTAMP NOT NULL,
  
  PRIMARY KEY id (id)
  );";


  $t_rating_meta = $wpdb->prefix . 'rating_meta';
  $sql_rating_meta = "CREATE TABLE $t_rating_meta (
  id int(11) NOT NULL AUTO_INCREMENT,
  entity_content_id int(11) NOT NULL DEFAULT 0,
  user_id int(11) NOT NULL DEFAULT 0,
  entity_type_name VARCHAR(50) NOT NULL,
  factor_name VARCHAR(50) NULL DEFAULT NULL,
  rating_score int(11) NOT NULL DEFAULT 0,
  rating_stars_count int(11) NOT NULL DEFAULT 0,
  rating_weight int(11) NOT NULL DEFAULT 0,
  ip VARCHAR(255) NOT NULL,
  country VARCHAR(50) NULL DEFAULT NULL,
  state VARCHAR(50) NULL DEFAULT NULL,
  time TIMESTAMP NOT NULL,
  
  PRIMARY KEY id (id)
  );";


  dbDelta($sql_admin_rating_config);
  dbDelta($sql_rating_factors);
  dbDelta($sql_entity_rating_factors);
  dbDelta($sql_rating_score);
  dbDelta($sql_rating_meta);

  add_option("rating_db_version", $rating_db_version);
  
  $table = $wpdb->prefix . 'posts'; 
  $sql_get_post_type = $wpdb->get_results(" SELECT post_type FROM $table GROUP BY post_type");
  
  foreach($sql_get_post_type as $type) {
    $post_type[$type->post_type] = $type->post_type;
    $post_type['comment'] = 'comment';    
  }
  unset($post_type['revision']);
  
  $ar_custom_post_types = get_post_types(array( 'public' => true, '_builtin' => false ));
  
  if(count($ar_custom_post_types)> 0) {
   $post_type = array_merge($post_type, $ar_custom_post_types);
  }
  
  foreach($post_type as $val){
    $wpdb->insert($wpdb->prefix . 'admin_rating_config', array('entity_type_name' => $val,
                'most_rated_flag' => 0,
                'entity_factors_mode' => 1,
                'entity_enable' => 0,
                'theme' => 'default'), array('%s', '%d', '%d', '%d', '%s')
   );
  }
}

/* Delete table */
function Rating_uninstall() {
  global $wpdb;
  $wpdb->query("DROP TABLE IF EXISTS " . $wpdb->prefix . 'admin_rating_config');
  $wpdb->query("DROP TABLE IF EXISTS " . $wpdb->prefix . 'rating_factors');
  $wpdb->query("DROP TABLE IF EXISTS " . $wpdb->prefix . 'entity_rating_factors');
  //    $wpdb->query("DROP TABLE IF EXISTS " . $wpdb->prefix . 'rating_scores');
  $wpdb->query("DROP TABLE IF EXISTS " . $wpdb->prefix . 'rating_meta');
  delete_option('rating_theme_settings');
  delete_option('advanced_rating_settings');
}

register_activation_hook(__FILE__, 'Rating_install');
register_deactivation_hook(__FILE__, 'Rating_uninstall');


// Initialize the plugin
add_action('plugins_loaded', create_function( '', '$rating_settings_tabs = new RatingSettings;' ));


/**
 * Method to create share links
 * @param object $content
 * @return object
 */
function add_share_post_content($content) {
  $advancedOptions = get_option('advanced_rating_settings');
  if(isset($advancedOptions['enable_share']) && $advancedOptions['enable_share'] ==1) {
    $rating_settings = new RatingSettings;
    if(!is_feed() && !is_home()) {
      $content .= $rating_settings->share_rating($content);
    }
  }
  return $content;
}
add_filter('the_content', 'add_share_post_content');


function my_custom_js() {
  ?>
<script type="text/javascript">
    var pluginUrl = '<?php echo plugins_url(); ?>' ;
    var ajax_url = '<?php echo admin_url('admin-ajax.php'); ?>';
    var adminRatingTaburl = '<?php echo admin_url().'options-general.php?page=rating_options&tab=rating_settings'?>';
  </script>
<?php }
// Add hook for admin <head></head>
add_action('admin_head', 'my_custom_js');
// Add hook for front-end <head></head>
add_action('wp_head', 'my_custom_js');
